@@ -41,9 +41,9 @@
 #include "layers/selections/image/kpRectangularImageSelection.h"
 #include "kpLogCategories.h"
 
-#include <qapplication.h>
-#include <qmatrix.h>
-#include <qpolygon.h>
+#include <QApplication>
+#include <QTransform>
+#include <QPolygon>
 
 // TODO: nasty, should avoid using GUI class in this command class
 #include "dialogs/imagelib/transforms/kpTransformSkewDialog.h"
@@ -74,10 +74,7 @@ QString kpTransformSkewCommand::name () const
 {
     QString opName = i18n ("Skew");
 
-    if (m_actOnSelection)
-        return i18n ("Selection: %1", opName);
-    else
-        return opName;
+    return (m_actOnSelection) ? i18n ("Selection: %1", opName) : opName;
 }
 
 
@@ -123,7 +120,7 @@ void kpTransformSkewCommand::execute ()
         QPolygon currentPoints = sel->calculatePoints ();
         currentPoints.translate (-currentPoints.boundingRect ().x (),
                                  -currentPoints.boundingRect ().y ());
-        QMatrix skewMatrix = kpPixmapFX::skewMatrix (
+        QTransform skewMatrix = kpPixmapFX::skewMatrix (
             doc->image (m_actOnSelection),
             kpTransformSkewDialog::horizontalAngleForPixmapFX (m_hangle),
             kpTransformSkewDialog::verticalAngleForPixmapFX (m_vangle));
@@ -150,8 +147,7 @@ void kpTransformSkewCommand::execute ()
                        << currentPoints.boundingRect ()
                        << " newPixmap: w=" << newImage.width ()
                        << " h=" << newImage.height ()
-                       << " (victim of rounding error and/or skewed-a-(rectangular)-pixmap-that-was-transparent-in-the-corners-making-sel-uselessly-bigger-than-needs-be))"
-                       << endl;
+                       << " (victim of rounding error and/or skewed-a-(rectangular)-pixmap-that-was-transparent-in-the-corners-making-sel-uselessly-bigger-than-needs-be))";
         #endif
             doc->setSelection (
                 kpRectangularImageSelection (
