@@ -42,7 +42,6 @@
 #include <QSpinBox>
 
 #include "kpLogCategories.h"
-#include <kiconloader.h>
 #include <KLocalizedString>
 
 #include "kpDefs.h"
@@ -103,7 +102,7 @@ void kpTransformSkewDialog::createAngleGroupBox ()
 
 
     auto *horizontalSkewPixmapLabel = new QLabel (angleGroupBox);
-    horizontalSkewPixmapLabel->setPixmap (UserIcon (QStringLiteral("image_skew_horizontal")));
+    horizontalSkewPixmapLabel->setPixmap (QStringLiteral(":/icons/image_skew_horizontal"));
 
     auto *horizontalSkewLabel = new QLabel (i18n ("&Horizontal:"), angleGroupBox);
     m_horizontalSkewInput = new QSpinBox;
@@ -115,7 +114,7 @@ void kpTransformSkewDialog::createAngleGroupBox ()
 
 
     auto *verticalSkewPixmapLabel = new QLabel (angleGroupBox);
-    verticalSkewPixmapLabel->setPixmap (UserIcon (QStringLiteral("image_skew_vertical")));
+    verticalSkewPixmapLabel->setPixmap (QStringLiteral(":/icons/image_skew_vertical"));
 
     auto *verticalSkewLabel = new QLabel (i18n ("&Vertical:"), angleGroupBox);
     m_verticalSkewInput = new QSpinBox;
