@@ -111,13 +111,11 @@ public:
                                   const QUrl &url,
                                   const kpDocumentSaveOptions &saveOptions,
                                   const kpDocumentMetaInfo &metaInfo,
-                                  bool overwritePrompt,
                                   bool lossyPrompt,
                                   QWidget *parent);
-    bool save (bool overwritePrompt = false, bool lossyPrompt = false);
+    bool save (bool lossyPrompt = false);
     bool saveAs (const QUrl &url,
                  const kpDocumentSaveOptions &saveOptions,
-                 bool overwritePrompt = true,
                  bool lossyPrompt = true);
 
 
@@ -125,7 +123,7 @@ public:
     bool savedAtLeastOnceBefore () const;
 
     QUrl url () const;
-    void setURL (const QUrl &url, bool isFromURL);
+    void setURL (const QUrl &url, bool isFromExistingURL);
 
     // Returns whether the document's image was successfully opened from
     // or saved to the URL returned by url().  This is not true for a
@@ -139,7 +137,10 @@ public:
     //
     // e.g. If the user types "kolourpaint doesnotexist.png" to start
     //      KolourPaint, this method will return false.
-    bool isFromURL (bool checkURLStillExists = true) const;
+    bool isFromExistingURL () const;
+
+    // Checks whether @p url still exists
+    bool urlExists (const QUrl &url) const;
 
     // (will convert: empty Url --> "Untitled")
     QString prettyUrl () const;
@@ -337,7 +338,7 @@ private:
     kpImage *m_image;
 
     QUrl m_url;
-    bool m_isFromURL;
+    bool m_isFromExistingURL;
     bool m_savedAtLeastOnceBefore;
 
     kpDocumentSaveOptions *m_saveOptions;
