@@ -37,11 +37,9 @@
 
 
 class QCursor;
-class QDragMoveEvent;
 class QEvent;
 class QKeyEvent;
 class QMouseEvent;
-class QPaintEvent;
 class QRect;
 class QResizeEvent;
 class QTimer;
