@@ -32,11 +32,11 @@
 #include "views/manager/kpViewManager.h"
 #include "kpViewManagerPrivate.h"
 
-#include <qapplication.h>
-#include <qlist.h>
-#include <qtimer.h>
+#include <QApplication>
+#include <QList>
+#include <QTimer>
 
-#include <kdebug.h>
+#include "kpLogCategories.h"
 
 #include "kpDefs.h"
 #include "document/kpDocument.h"
@@ -58,7 +58,7 @@ void kpViewManager::setQueueUpdates ()
 {
     d->queueUpdatesCounter++;
 #if DEBUG_KP_VIEW_MANAGER && 1
-    kDebug () << "kpViewManager::setQueueUpdates() counter="
+    qCDebug(kpLogViews) << "kpViewManager::setQueueUpdates() counter="
                << d->queueUpdatesCounter << endl;
 #endif
 }
@@ -68,8 +68,8 @@ void kpViewManager::restoreQueueUpdates ()
 {
     d->queueUpdatesCounter--;
 #if DEBUG_KP_VIEW_MANAGER && 1
-    kDebug () << "kpViewManager::restoreQueueUpdates() counter="
-               << d->queueUpdatesCounter << endl;
+    qCDebug(kpLogViews) << "kpViewManager::restoreQueueUpdates() counter="
+               << d->queueUpdatesCounter;
 #endif
     Q_ASSERT (d->queueUpdatesCounter >= 0);
 
@@ -96,7 +96,7 @@ void kpViewManager::setFastUpdates ()
 {
     d->fastUpdatesCounter++;
 #if DEBUG_KP_VIEW_MANAGER && 0
-    kDebug () << "kpViewManager::setFastUpdates() counter="
+    qCDebug(kpLogViews) << "kpViewManager::setFastUpdates() counter="
                << d->fastUpdatesCounter << endl;
 #endif
 }
@@ -106,7 +106,7 @@ void kpViewManager::restoreFastUpdates ()
 {
     d->fastUpdatesCounter--;
 #if DEBUG_KP_VIEW_MANAGER && 0
-    kDebug () << "kpViewManager::restoreFastUpdates() counter="
+    qCDebug(kpLogViews) << "kpViewManager::restoreFastUpdates() counter="
                << d->fastUpdatesCounter << endl;
 #endif
     Q_ASSERT (d->fastUpdatesCounter >= 0);
@@ -124,13 +124,16 @@ void kpViewManager::updateView (kpView *v, const QRect &viewRect)
 {
     if (!queueUpdates ())
     {
-        if (fastUpdates ())
+        if (fastUpdates ()) {
             v->repaint (viewRect);
-        else
+        }
+        else {
             v->update (viewRect);
+        }
     }
-    else
+    else {
         v->addToQueuedArea (viewRect);
+    }
 }
 
 // public slot
@@ -144,21 +147,25 @@ void kpViewManager::updateView (kpView *v, const QRegion &viewRegion)
 {
     if (!queueUpdates ())
     {
-        if (fastUpdates ())
+        if (fastUpdates ()) {
             v->repaint (viewRegion);
-        else
+        }
+        else {
             v->update (viewRegion.boundingRect ());
+        }
     }
-    else
+    else {
         v->addToQueuedArea (viewRegion);
+    }
 }
 
 
 // public slot
 void kpViewManager::updateViewRectangleEdges (kpView *v, const QRect &viewRect)
 {
-    if (viewRect.height () <= 0 || viewRect.width () <= 0)
+    if (viewRect.height () <= 0 || viewRect.width () <= 0) {
         return;
+    }
 
     // Top line
     updateView (v, QRect (viewRect.x (), viewRect.y (),
@@ -186,20 +193,11 @@ void kpViewManager::updateViewRectangleEdges (kpView *v, const QRect &viewRect)
     }
 }
 
-
-// public slot
-void kpViewManager::updateViews ()
-{
-    kpDocument *doc = document ();
-    if (doc)
-        updateViews (QRect (0, 0, doc->width (), doc->height ()));
-}
-
 // public slot
 void kpViewManager::updateViews (const QRect &docRect)
 {
 #if DEBUG_KP_VIEW_MANAGER && 0
-    kDebug () << "kpViewManager::updateViews (" << docRect << ")";
+    qCDebug(kpLogViews) << "kpViewManager::updateViews (" << docRect << ")";
 #endif
 
     for (QLinkedList <kpView *>::const_iterator it = d->views.begin ();
@@ -209,12 +207,12 @@ void kpViewManager::updateViews (const QRect &docRect)
         kpView *view = *it;
 
     #if DEBUG_KP_VIEW_MANAGER && 0
-        kDebug () << "\tupdating view " << view->name ();
+        qCDebug(kpLogViews) << "\tupdating view " << view->name ();
     #endif
         if (view->zoomLevelX () % 100 == 0 && view->zoomLevelY () % 100 == 0)
         {
         #if DEBUG_KP_VIEW_MANAGER && 0
-            kDebug () << "\t\tviewRect=" << view->transformDocToView (docRect);
+            qCDebug(kpLogViews) << "\t\tviewRect=" << view->transformDocToView (docRect);
         #endif
             updateView (view, view->transformDocToView (docRect));
         }
@@ -231,25 +229,19 @@ void kpViewManager::updateViews (const QRect &docRect)
                                 .intersected (QRect (0, 0, view->width (), view->height ()));
 
         #if DEBUG_KP_VIEW_MANAGER && 0
-            kDebug () << "\t\tviewRect (+compensate)=" << newRect;
+            qCDebug(kpLogViews) << "\t\tviewRect (+compensate)=" << newRect;
         #endif
             updateView (view, newRect);
         }
     }
 }
 
-// public slot
-void kpViewManager::updateViews (int x, int y, int w, int h)
-{
-    updateViews (QRect (x, y, w, h));
-}
-
 
 // public slot
 void kpViewManager::adjustViewsToEnvironment ()
 {
 #if DEBUG_KP_VIEW_MANAGER && 1
-    kDebug () << "kpViewManager::adjustViewsToEnvironment()"
+    qCDebug(kpLogViews) << "kpViewManager::adjustViewsToEnvironment()"
                << " numViews=" << d->views.count ()
                << endl;
 #endif
@@ -260,7 +252,7 @@ void kpViewManager::adjustViewsToEnvironment ()
         kpView *view = *it;
 
     #if DEBUG_KP_VIEW_MANAGER && 1
-        kDebug () << "\tview: " << view->name ()
+        qCDebug(kpLogViews) << "\tview: " << view->name ()
                    << endl;
     #endif
         view->adjustToEnvironment ();
